# Effective Quantum Simulator for Networks (EQSN)

EQSN is a library for simulating quantum networks.
It is developed as a backend for the
[QuNetSim](https://github.com/tqsd/QuNetSim) package, but can also be used as a standalone library.

The documentation can be found [here](https://tqsd.github.io/EQSN_python/_build/index.html).
